@@ -13,7 +13,8 @@ __all__ = ["ddb_to_event"]
 deserialize = TypeDeserializer().deserialize
 
 VALID_EVENT_TYPE = {
-    "InventoryUpdateRequest" :  "InventoryUpdateRequest"
+    "InventoryUpdateRequest" :  "InventoryUpdateRequest",
+    "RequisitionItemReleaseEvent":"RequisitionItemReleaseEvent"
 
 }
 
